@@ -85,6 +85,9 @@ def tests(session: PowerSession, coverage, pkg_specs):
     # install all requirements
     session.install_reqs(setup=True, install=True, tests=True, versions_dct=pkg_specs)
 
+    # Since our tests are currently limited, use our own doc generation as a test
+    session.install_reqs(phase="tests", phase_reqs=MKDOCS_GALLERY_EXAMPLES_REQS)
+
     # install CI-only dependencies
     # if install_ci_deps:
     #     session.install2("keyrings.alt")
@@ -102,40 +105,47 @@ def tests(session: PowerSession, coverage, pkg_specs):
     # finally run all tests
     if not coverage:
         # install self so that it is recognized by pytest
-        session.run2("pip install . --no-deps")
+        session.install2('.', '--no-deps')
 
         # simple: pytest only
         session.run2("python -m pytest --cache-clear -v tests/")
+
+        # since our tests are too limited, we use our own mkdocs build as additional test for now.
+        session.run2("python -m mkdocs build")
+        # -- add a second build so that we can go through the caching/md5 side
+        session.run2("python -m mkdocs build")
     else:
         # install self in "develop" mode so that coverage can be measured
-        session.run2("pip install -e . --no-deps")
+        session.install2('-e', '.', '--no-deps')
 
         # coverage + junit html reports + badge generation
         session.install_reqs(phase="coverage",
-                             phase_reqs=["coverage", "pytest-html", "genbadge[tests,coverage]", "mkdocs"]
-                                        + MKDOCS_GALLERY_EXAMPLES_REQS,
+                             phase_reqs=["coverage", "pytest-html", "genbadge[tests,coverage]"],
                              versions_dct=pkg_specs)
 
         # --coverage + junit html reports
         session.run2("coverage run --source src/{pkg_name} "
-                     "-m pytest --cache-clear --junitxml={test_xml} --html={test_html} -v tests/"
+                     "-m pytest --cache-clear --junitxml='{test_xml}' --html='{test_html}' -v tests/"
                      "".format(pkg_name=pkg_name, test_xml=Folders.test_xml, test_html=Folders.test_html))
 
         # -- use the doc generation for coverage
+        session.run2("coverage run --append --source src/{pkg_name} -m mkdocs build"
+                     "".format(pkg_name=pkg_name, test_xml=Folders.test_xml, test_html=Folders.test_html))
+        # -- add a second build so that we can go through the caching/md5 side
         session.run2("coverage run --append --source src/{pkg_name} -m mkdocs build"
                      "".format(pkg_name=pkg_name, test_xml=Folders.test_xml, test_html=Folders.test_html))
 
         session.run2("coverage report")
-        session.run2("coverage xml -o {covxml}".format(covxml=Folders.coverage_xml))
-        session.run2("coverage html -d {dst}".format(dst=Folders.coverage_reports))
+        session.run2("coverage xml -o '{covxml}'".format(covxml=Folders.coverage_xml))
+        session.run2("coverage html -d '{dst}'".format(dst=Folders.coverage_reports))
         # delete this intermediate file, it is not needed anymore
         rm_file(Folders.coverage_intermediate_file)
 
         # --generates the badge for the test results and fail build if less than x% tests pass
         nox_logger.info("Generating badge for tests coverage")
         # Use our own package to generate the badge
-        session.run2("genbadge tests -i %s -o %s -t 100" % (Folders.test_xml, Folders.test_badge))
-        session.run2("genbadge coverage -i %s -o %s" % (Folders.coverage_xml, Folders.coverage_badge))
+        session.run2("genbadge tests -i '%s' -o '%s' -t 100" % (Folders.test_xml, Folders.test_badge))
+        session.run2("genbadge coverage -i '%s' -o '%s'" % (Folders.coverage_xml, Folders.coverage_badge))
 
 
 @power_session(python=PY38, logsdir=Folders.runlogs)
@@ -144,7 +154,7 @@ def flake8(session: PowerSession):
 
     session.install("-r", str(Folders.ci_tools / "flake8-requirements.txt"))
     session.install("genbadge[flake8]")
-    session.run2("pip install .")
+    session.install2('.')
 
     rm_folder(Folders.flake8_reports)
     Folders.flake8_reports.mkdir(parents=True, exist_ok=True)
@@ -156,7 +166,7 @@ def flake8(session: PowerSession):
     session.run("flake8", pkg_name, "--exit-zero", "--format=html", "--htmldir", str(Folders.flake8_reports),
                 "--statistics", "--tee", "--output-file", str(Folders.flake8_intermediate_file))
     # generate our badge
-    session.run2("genbadge flake8 -i %s -o %s" % (Folders.flake8_intermediate_file, Folders.flake8_badge))
+    session.run2("genbadge flake8 -i '%s' -o '%s'" % (Folders.flake8_intermediate_file, Folders.flake8_badge))
     rm_file(Folders.flake8_intermediate_file)
 
 
@@ -177,7 +187,7 @@ def docs(session: PowerSession):
     session.install_reqs(phase="docs", phase_reqs=["mkdocs"] + MKDOCS_GALLERY_EXAMPLES_REQS)
 
     # Install the plugin
-    session.run2("pip install .")
+    session.install2('.')
 
     if session.posargs:
         # use posargs instead of "serve"
@@ -196,7 +206,7 @@ def publish(session: PowerSession):
     )
 
     # Install the plugin
-    session.run2("pip install .")
+    session.install2('.')
 
     # possibly rebuild the docs in a static way (mkdocs serve does not build locally)
     session.run2("mkdocs build")
