@@ -17,12 +17,18 @@ import os
 import stat
 import weakref
 
-from typing import List, Dict, Any, Tuple, Union
+from typing import List, Dict, Any, Tuple, Union, Iterable
 
 from pathlib import Path
 
 from .errors import ExtensionError
-from .utils import _smart_copy_md5, get_md5sum, _replace_by_new_if_needed, _new_file
+from .utils import (_smart_copy_md5,
+                    get_md5sum,
+                    _replace_by_new_if_needed,
+                    _new_file,
+                    matches_filepath_pattern,
+                    is_relative_to,
+                    )
 
 
 def _has_readme(folder: Path) -> bool:
@@ -89,10 +95,47 @@ class ImagePathIterator:
         return path
 
 
+def gen_repr(hide: Union[str, Iterable] = (), show: Union[str, Iterable] = ()):
+    """
+    Generate a repr for a slotted class with either a list of shown or hidden attr names.
+
+    Parameters
+    ----------
+    hide
+    show
+
+    Returns
+    -------
+    __repr__ : Callable
+        The generated repr implementation
+    """
+    if show and hide:
+        raise ValueError("Either provide show or hide")
+
+    if isinstance(show, str):
+        show = (show, )
+
+    if isinstance(hide, str):
+        hide = (hide, )
+
+    def __repr__(self):
+        show_ = self.__slots__ if not show else show
+
+        attrs = ",".join("%s=%r" % (k, getattr(self, k))
+                         for k in show_
+                         if k not in hide
+                         )
+        return "%s(%s)" % (type(self).__name__, attrs)
+
+    return __repr__
+
+
 class GalleryScriptResults:
     """Result of running a single gallery file"""
     __slots__ = ("script", "intro", "exec_time", "memory", "thumb")
 
+    __repr__ = gen_repr()
+
     def __init__(self, script: "GalleryScript", intro: str, exec_time: float, memory: float, thumb: Path):
         self.script = script
         self.intro = intro
@@ -112,6 +155,8 @@ class ScriptRunVars:
         "image_path_iterator", "example_globals", "memory_used_in_blocks", "memory_delta", "fake_main", "stop_executing"
     )
 
+    __repr__ = gen_repr()
+
     def __init__(self, image_path_iterator: ImagePathIterator):
         # The iterator returning the next image file paths
         self.image_path_iterator = image_path_iterator
@@ -137,6 +182,8 @@ class GalleryScript:
 
     __slots__ = ("__weakref__", "_gallery", "script_stem", "title", "_py_file_md5", "run_vars")
 
+    __repr__ = gen_repr(hide=("__weakref__", "_gallery"))
+
     def __init__(self, gallery: "GalleryBase", script_src_file: Path):
         self._gallery = weakref.ref(gallery)
 
@@ -189,7 +236,7 @@ class GalleryScript:
             True if script has to be executed
         """
         filename_pattern = self.gallery_conf.get('filename_pattern')
-        execute = re.search(filename_pattern, str(self.src_py_file)) and self.gallery_conf['plot_gallery']
+        execute = matches_filepath_pattern(self.src_py_file, filename_pattern) and self.gallery_conf['plot_gallery']
         return execute
 
     @property
@@ -508,6 +555,8 @@ class GallerySubSection(GalleryBase):
     """Represents a subsection in a gallery."""
     __slots__ = ("__weakref__", "_parent", "subpath")
 
+    __repr__ = gen_repr(hide=("__weakref__", "_parent"))
+
     def has_subsections(self) -> bool:
         return False
 
@@ -578,6 +627,8 @@ class Gallery(GalleryBase):
     """
     __slots__ = ("__weakref__", "scripts_dir_rel_project", "generated_dir_rel_project", "subsections", "_all_info")
 
+    __repr__ = gen_repr(hide=("__weakref__", "subsections", "_all_info"))
+
     subpath = Path(".")
 
     def __init__(self, all_info: "AllInformation", scripts_dir_rel_project: Path, generated_dir_rel_project: Path):
@@ -615,7 +666,7 @@ class Gallery(GalleryBase):
         self._attach(all_info=all_info)
 
         # Check that generated dir is inside docs dir
-        if not self.generated_dir.as_posix().startswith(self.all_info.mkdocs_docs_dir.as_posix()):
+        if not is_relative_to(self.all_info.mkdocs_docs_dir, self.generated_dir):
             raise ValueError("Generated gallery dirs can only be located as subfolders of the mkdocs 'docs_dir'.")
 
     def has_subsections(self) -> bool:
@@ -749,6 +800,8 @@ class AllInformation:
     """Represent all galleries as well as the global configuration."""
     __slots__ = ("__weakref__", "galleries", "gallery_conf", "mkdocs_conf", "project_root_dir")
 
+    __repr__ = gen_repr(show="project_root_dir")
+
     def __init__(
         self,
         gallery_conf: Dict[str, Any],
