@@ -25,6 +25,7 @@ from . import glr_path_static
 from .binder import copy_binder_files
 # from .docs_resolv import embed_code_links
 from .gen_gallery import parse_config, generate_gallery_md, summarize_failing_examples, fill_mkdocs_nav
+from .utils import is_relative_to
 
 
 class ConfigList(co.OptionallyRequired):
@@ -64,7 +65,10 @@ class MySubConfig(co.SubConfig):
             return super(MySubConfig, self).validate(value)
 
     def run_validation(self, value):
-        """Fix SubConfig: errors and warnings were not caught"""
+        """Fix SubConfig: errors and warnings were not caught
+
+        See https://github.com/mkdocs/mkdocs/pull/2710
+        """
         failed, self.warnings = Config.validate(self)
         if len(failed) > 0:
             # get the first failing one
@@ -74,22 +78,34 @@ class MySubConfig(co.SubConfig):
         return self
 
 
+class Dir(co.Dir):
+    """mkdocs.config.config_options.Dir replacement: returns a pathlib object instead of a string"""
+    def run_validation(self, value):
+        return Path(co.Dir.run_validation(self, value))
+
+
+class File(co.File):
+    """mkdocs.config.config_options.File replacement: returns a pathlib object instead of a string"""
+    def run_validation(self, value):
+        return Path(co.File.run_validation(self, value))
+
+
 class GalleryPlugin(BasePlugin):
     #     # Mandatory to display plotly graph within the site
     #     import plotly.io as pio
     #     pio.renderers.default = "sphinx_gallery"
 
     config_scheme = (
-        ('conf_script', co.File(exists=True)),
+        ('conf_script', File(exists=True)),
         ('filename_pattern', co.Type(str)),
         ('ignore_pattern', co.Type(str)),
-        ('examples_dirs', ConfigList(co.Dir(exists=True))),
+        ('examples_dirs', ConfigList(Dir(exists=True))),
         # 'reset_argv': DefaultResetArgv(),
         ('subsection_order', co.Choice(choices=(None, "ExplicitOrder"))),
         ('within_subsection_order', co.Choice(choices=("FileNameSortKey", "NumberOfCodeLinesSortKey"))),
 
-        ('gallery_dirs', ConfigList(co.Dir(exists=False))),
-        ('backreferences_dir', co.Dir(exists=False)),
+        ('gallery_dirs', ConfigList(Dir(exists=False))),
+        ('backreferences_dir', Dir(exists=False)),
         ('doc_module', ConfigList(co.Type(str))),
         # 'reference_url': {},  TODO how to link code to external functions?
         ('capture_repr', ConfigList(co.Type(str))),
@@ -103,14 +119,14 @@ class GalleryPlugin(BasePlugin):
         # 'passing_examples': [],
         # 'stale_examples': [],
         ('run_stale_examples', co.Type(bool)),
-        ('expected_failing_examples', ConfigList(co.File(exists=True))),
+        ('expected_failing_examples', ConfigList(File(exists=True))),
         ('thumbnail_size', ConfigList(co.Type(int), single_elt_allowed=False)),
         ('min_reported_time', co.Type(int)),
         ('binder', MySubConfig(
             # Required keys
             ('org', co.Type(str, required=True)),
             ('repo', co.Type(str, required=True)),
-            ('dependencies', ConfigList(co.File(exists=True), required=True)),
+            ('dependencies', ConfigList(File(exists=True), required=True)),
             # Optional keys
             ('branch', co.Type(str, required=True, default="gh-pages")),
             ('binderhub_url', co.URL(required=True, default="https://mybinder.org")),
@@ -134,7 +150,7 @@ class GalleryPlugin(BasePlugin):
         # 'css': _KNOWN_CSS,
         ('matplotlib_animations', co.Type(bool)),
         ('image_srcset', ConfigList(co.Type(str))),
-        ('default_thumb_file', co.File(exists=True)),
+        ('default_thumb_file', File(exists=True)),
         ('line_numbers', co.Type(bool)),
     )
 
@@ -333,8 +349,7 @@ markdown_extensions:
         def wrap_callback(original_callback):
             def _callback(event):
                 for g in excluded_dirs:
-                    # TODO maybe use fnmatch rather ?
-                    if event.src_path.startswith(g):
+                    if is_relative_to(g, Path(event.src_path)):
                         # ignore this event: the file is in the gallery target dir.
                         # log.info(f"Ignoring event: {event}")
                         return
